@@ -2,13 +2,13 @@
 -- Module: Network.Greskell.WebSocket
 -- Description: Client of Gremlin Server using WebSocket
 -- Maintainer: Toshio Ito <debug.ito@gmail.com>
--- 
+--
 module Network.Greskell.WebSocket
-       ( module Network.Greskell.WebSocket.Client
-         -- $doc
-       ) where
+    ( -- $doc
+      module Network.Greskell.WebSocket.Client
+    ) where
 
-import Network.Greskell.WebSocket.Client
+import           Network.Greskell.WebSocket.Client
 
 -- $doc
 --
