@@ -262,7 +262,7 @@ runMuxLoop wsconn req_pool settings qreq qres readConnState rx_thread = loop
                              <|> (EvRes <$> readTQueue qres)
                              <|> makeEvActiveClose
                              <|> (rxResultToEvent <$> waitCatchSTM rx_thread)
-                             <|> (timeoutToEvent <$> waitAnySTM res_timers)
+                             <|> waitResponseTimeout res_timers
         where
           max_concurrency = Settings.concurrency settings
           cur_concurrency = length res_timers
@@ -278,6 +278,10 @@ runMuxLoop wsconn req_pool settings qreq qres readConnState rx_thread = loop
               else do
                 conn_state <- readConnState
                 if conn_state == ConnOpen then empty else return EvActiveClose
+          waitResponseTimeout timers =
+            if null timers
+            then empty
+            else timeoutToEvent <$> waitAnySTM timers
     handleReq req = do
       insert_ok <- tryInsertToReqPool req_pool rid makeNewEntry
       if insert_ok
