@@ -1,13 +1,13 @@
 module TestUtil.Env
-       ( requireEnv,
-         withEnvForExtServer,
-         withEnvForIntServer
-       ) where
+    ( requireEnv
+    , withEnvForExtServer
+    , withEnvForIntServer
+    ) where
 
-import System.Environment (lookupEnv)
-import Test.Hspec
+import           System.Environment                    (lookupEnv)
+import           Test.Hspec
 
-import Network.Greskell.WebSocket.Connection (Host, Port)
+import           Network.Greskell.WebSocket.Connection (Host, Port)
 
 requireEnv :: String -> IO String
 requireEnv env_key = maybe bail return =<< lookupEnv env_key
